Vertex

Type Alias Vertex 

pub type Vertex = Matrix<f32, U4, U1, MatrixArray<f32, U4, U1>>;
A type for custom mesh vertices. Initialize with vertex.

Aliased Type

pub struct Vertex {
    pub data: ArrayStorage<f32, U4, U1>,
    /* private fields */
}

Fields

data: ArrayStorage<f32, U4, U1>

The data storage that contains all the matrix components and informations about its number of rows and column (if needed).